Crate minco_plugin_idempotency

Crate minco_plugin_idempotency 

Atomic idempotency claims, request fingerprints, and deterministic replay primitives.

Structs

IdempotencyKey
IdempotencyLease
Exclusive claim returned before a caller performs the side effect.
IdempotencyPlugin
IdempotencyRecord
IdempotencyService
MemoryIdempotencyStore
RequestFingerprint

Enums

BeginOutcome
IdempotencyError

Traits

IdempotencyStore

Functions

validate_claim_timeout